fn new_chunk<T>() -> Box<[MaybeUninit<T>; 65536]>Expand description
Allocate a fresh chunk on the heap without ever materializing a
CHUNK_SIZE-element array on the stack.
fn new_chunk<T>() -> Box<[MaybeUninit<T>; 65536]>Allocate a fresh chunk on the heap without ever materializing a
CHUNK_SIZE-element array on the stack.