pub struct StoreReadGuard<'a> {
guard: RwLockReadGuard<'a, StoreWithGeneration>,
}Fields
guard: RwLockReadGuard<'a, StoreWithGeneration>Implementations
Sourceimpl StoreReadGuard<'_>
impl StoreReadGuard<'_>
pub fn generation(&self) -> usize
Methods from Deref<Target = Store>
pub fn has_time_info(&self) -> bool
pub fn set_max_self_time_lookup(&self, time: Timestamp)
Sourcepub fn memory_samples_for_range(
&self,
start: Timestamp,
end: Timestamp,
) -> Vec<u64>
pub fn memory_samples_for_range( &self, start: Timestamp, end: Timestamp, ) -> Vec<u64>
Returns up to MAX_MEMORY_SAMPLES memory samples in the range
[start, end]. When more samples exist, groups of N consecutive
samples are merged by taking the maximum memory value in each group.
Sourcepub fn memory_samples_for_range_with_ts(
&self,
start: Timestamp,
end: Timestamp,
) -> Vec<(Timestamp, u64, u8)>
pub fn memory_samples_for_range_with_ts( &self, start: Timestamp, end: Timestamp, ) -> Vec<(Timestamp, u64, u8)>
Like memory_samples_for_range but keeps the timestamps and the
memory-pressure byte. Timestamps are absolute store timestamps (same
reference frame as span start/end). When the raw slice exceeds
MAX_MEMORY_SAMPLES, each merged group is represented by the sample
whose memory value was the group’s max (its timestamp and pressure
byte are kept alongside it).
Sourcepub fn memory_pressure_samples_for_range(
&self,
start: Timestamp,
end: Timestamp,
) -> Vec<u8> ⓘ
pub fn memory_pressure_samples_for_range( &self, start: Timestamp, end: Timestamp, ) -> Vec<u8> ⓘ
Returns up to MAX_MEMORY_SAMPLES memory pressure values in the range
[start, end]. The returned slice has the same length and group
boundaries as Self::memory_samples_for_range so that the two
results can be rendered in parallel. Each group is downsampled by
taking the maximum pressure value.
fn memory_samples_slice( &self, start: Timestamp, end: Timestamp, ) -> &[(Timestamp, u64, u8)]
pub fn root_spans(&self) -> impl Iterator<Item = SpanRef<'_>>
pub fn root_span(&self) -> SpanRef<'_>
pub fn span(&self, id: NonZeroUsize) -> Option<(SpanRef<'_>, bool)>